#
# spec file for package sbd
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Lars Marowsky-Bree
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           sbd
Version:        1.4.0+20190514.e9be8d9
Release:        lp151.2.3.1
Summary:        Storage-based death
License:        GPL-2.0-or-later
Group:          Productivity/Clustering/HA
Url:            https://github.com/ClusterLabs/sbd
Source:         %{name}-%{version}.tar.xz
Patch1:         bsc#1140065-Fix-sbd-cluster-exit-if-cmap-is-disconnected.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  libaio-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(corosync)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libqb)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pacemaker)
BuildRequires:  pkgconfig(pacemaker-cib)
BuildRequires:  pkgconfig(uuid)
Requires(post): %fillup_prereq
Conflicts:      ClusterTools2 < 2.3.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
This package contains the storage-based death functionality.

%prep
%autosetup -n %{name}-%{version} -p1

%build
autoreconf -fvi
%configure
make %{?_smp_mflags}

%install
%make_install LIBDIR=%{_libdir}
install -D -m 0755 src/sbd.sh %{buildroot}%{_datadir}/sbd/sbd.sh
install -D -m 0644 src/sbd.service %{buildroot}/%{_unitdir}/sbd.service
install -D -m 0644 src/sbd_remote.service %{buildroot}/%{_unitdir}/sbd_remote.service
ln -s service %{buildroot}%{_sbindir}/rcsbd
ln -s service %{buildroot}%{_sbindir}/rcsbd_remote
mkdir -p %{buildroot}%{_fillupdir}
install -m 0644 src/sbd.sysconfig %{buildroot}%{_fillupdir}/sysconfig.sbd

%post
%service_add_post sbd.service sbd_remote.service

if [ ! -e %{_sysconfdir}/sysconfig/sbd ]; then
    %fillup_only sbd
fi

%pre
%service_add_pre sbd.service sbd_remote.service

%preun
%service_del_preun -n sbd.service sbd_remote.service

%postun
%service_del_postun -n sbd.service sbd_remote.service

%files
%defattr(-,root,root)
%{_libdir}/stonith/
%{_sbindir}/sbd
%{_sbindir}/rcsbd
%{_sbindir}/rcsbd_remote
%{_datadir}/sbd
%{_mandir}/man8/sbd*
%{_unitdir}/sbd.service
%{_unitdir}/sbd_remote.service
%{_fillupdir}/sysconfig.sbd
%doc COPYING

%changelog
* Tue Jul  2 2019 jtomasiak@suse.com
- sbd-cluster: Fix 100%% CPU usage when CMAP connection is lost (bsc#1140065, SOC-8774)
  * bsc#1140065-Fix-sbd-cluster-exit-if-cmap-is-disconnected.patch
* Tue May 14 2019 Yan Gao <ygao@suse.com>
- Update to version 1.4.0+20190514.e9be8d9:
- sbd-inquisitor: Avoid flooding logs with messages that hint the default/configured timeout action (bsc#1134496)
* Tue Apr 30 2019 Yan Gao <ygao@suse.com>
- Update to version 1.4.0+20190416.5e3283c:
- sbd-inquisitor: overhaul device-list-parser
- sbd-inquisitor: free timeout action on bail out
- sbd-md: prevent unrealistic overflow on sector io calc
* Tue Apr  2 2019 Yan Gao <ygao@suse.com>
- Update to version 1.4.0+20190326.c38c5e6:
- sbd-pacemaker: bail out of status earlier
- sbd-pacemaker: make handling of cib-connection loss more robust
* Mon Mar 11 2019 Yan Gao <ygao@suse.com>
- Update to version 1.4.0+20190311.0159a3c:
- sbd-cluster: finalize cmap connection if disconnected from cluster (bsc#1128059)
* Tue Feb 12 2019 ygao@suse.com
- Update to version 1.4.0+20190201.f949aa8:
- fail earlier on invalid servants
* Thu Jan 24 2019 ygao@suse.com
- Update to version 1.4.0+20190123.1829c40:
- sbd.sysconfig: watchdog timeout set in the on-disk metadata takes precedence
- sbd.8.pod: use the generic term "cluster services" instead of the specific "openais" (bsc#1112918)
* Thu Jan 17 2019 ygao@suse.com
- Update to version 1.4.0+20190114.7f33d1a (v1.4.0)
* Wed Jan  9 2019 ygao@suse.com
- Update to version 1.3.1+20181218.dbae8ab:
- make timeout-action executed by sbd configurable
- use pacemaker's new pe api with constructors/destructors
* Thu Oct  4 2018 ygao@suse.com
- Update to version 1.3.1+20180920.bf16663:
- sbd-common: avoid statting potential links
- sbd-inquisitor: SBD_DELAY_START can be configured with a delay value (bsc#1107321)
- sbd-common: don't follow symlinks outside /dev for watchdog
* Fri Jul 27 2018 ygao@suse.com
- Update to version 1.3.1+20180703.f95b98e (bsc#1102930)
* Tue May  8 2018 ygao@suse.com
- Update to version 1.3.1+20180507.e102d9e:
- sbd-md: return error if faied to list any devices (bsc#1086650)
- sbd-cluster: let scan do the job of proc-parsing
- sbd-cluster: search for pacemaker-remoted
* Wed May  2 2018 ygao@suse.com
- Update to version 1.3.1+20180502.970d913:
- Log: upgrade important messages and downgrade unimportant ones (bsc#1091839)
- Log: change sbd's default logging level to LOG_NOTICE (bsc#1091839)
* Sat Mar 17 2018 ygao@suse.com
- Update to version 1.3.1+20180316.8873890:
- Fix: add Documentation value to systemd services
* Tue Mar 13 2018 ygao@suse.com
- Update to version 1.3.1+20180313.fe5fe1d:
- Build: sbd-pacemaker: Query CIB directly with the API instead of get_cib_copy() (bsc#1084689)
* Mon Feb  5 2018 jengelh@inai.de
- Combine %%service_* calls to reduce amount of generated code.
- Use %%make_install, and make sure directories are owned.
* Mon Feb  5 2018 ygao@suse.com
- Update to version 1.3.1+20180202.cc3e4cb:
- Doc: sbd.8.pod: add sections for query-watchdog & test-watchdog
- sbd-md: dump_headers returns 0 even open_device failed (bsc#1079316)
* Sat Dec 23 2017 ygao@suse.com
- Update to version 1.3.1+20171220.1e93740:
- Fix: systemd: make pacemaker & dlm wait for sbd-start to complete
- Doc: sbd.sysconfig: mention timeout caveat with SBD_DELAY_START (bsc#1074038)
* Fri Dec  1 2017 ygao@suse.com
- Update to version 1.3.1+20171130.ecbdf9c:
- Build: cluster-servant: Compile with pacemaker-2.0
* Wed Nov 29 2017 ygao@suse.com
- Fix: build error with glibc 2.25
- Fix: gcc format string error
- Upstream version cs: a7a7d792b9922f19bbace276c8a154e157a4f99c
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Nov  3 2017 ygao@suse.com
- Bump to 1.3.1
- Add commands to test/query watchdogs
- Upstream version cs: a74b4d25a3eb93fe1abbe6e3ebfd2b16cf48873f (v1.3.1)
* Fri Nov  3 2017 ygao@suse.com
- man: Call "-P" option "Pacemaker integration" in the description (bsc#1033600)
- sbd-inquisitor: Do not use watchdog if the conflicting options "-W" and "-w /dev/null" are both supplied (bsc#1047376)
  * Drop bug-1047376_sbd-not-use-watchdog-conflicting-options.patch which has been merged upstream
- sbd-inquisitor: Enable pacemaker integration by default as advertised in sysconfig.sbd (bsc#1046421, bsc#1033600)
  * Drop bug-1046421_sbd-enable-pacemaker-integration-by-default.patch which has been merged upstream
- sbd-inquisitor: Respect the obsolete option SBD_WATCHDOG for backward compatibility (bsc#1047372)
  * Drop bug-1047372_sbd-SBD_WATCHDOG-compatibility.patch which has been merged upstream
- Upstream version cs: 681ce1acbda12754eb97fb91f9a7306ff368452f
* Fri Nov  3 2017 ygao@suse.com
- cluster-servant: check for corosync 2Node mode
- disk-servant: signal reset request via exit-code
- improve reboot after sysrq_trigger
- Upstream version cs: 8a0800cc906d7bb8f8ac0d5664bdf691b2ca7690
* Fri Jul 21 2017 ygao@suse.com
- Fix node name parameter in manpage
- Don't reboot if off is requested
- sbd-inquisitor: cleanup_servant_by_pid() should be static
  * Drop sbd-cleanup_servant_by_pid-static.patch which has been merged upstream
- sbd.sh: Use a more obvious variable on parsing devices (bsc#1033934)
- sbd-inquisitor: Do not create duplicate servants (bsc#1033934, bsc#1065748)
- sbd-inquisitor: Correctly look up servant by device name (bsc#1033934, bsc#1065748)
- Upstream version cs: 11262fbc80364f2993a9876a2be82f4170c41e4e
* Tue Jul  4 2017 ygao@suse.com
- sbd-inquisitor: Do not use watchdog if the conflicting options "-W" and "-w /dev/null" are both supplied (bsc#1047376)
  * bug-1047376_sbd-not-use-watchdog-conflicting-options.patch
- sbd-inquisitor: Enable pacemaker integration by default as advertised in sysconfig.sbd (bsc#1046421, bsc#1033600)
  * bug-1046421_sbd-enable-pacemaker-integration-by-default.patch
- sbd-inquisitor: Respect the obsolete option SBD_WATCHDOG for backward compatibility (bsc#1047372)
  * bug-1047372_sbd-SBD_WATCHDOG-compatibility.patch
* Fri Jun  2 2017 ygao@suse.com
- sbd-inquisitor: cleanup_servant_by_pid() should be static
  * sbd-cleanup_servant_by_pid-static.patch
- sbd.sh: Correctly handle SBD_DELAY_START for multiple SBD devices (bsc#1033934)
- sbd.sh: consistent use of SBD_BIN (bsc#1033934)
- Upstream version cs: a0bc43b17fcb997fe4c09731db2126ab350cfb50
* Wed May 31 2017 ygao@suse.com
- Update to v1.3.0
- spec: Do not automatically try to restart sbd.service on update (bsc#1033934)
- Upstream version cs: 4968e9c8602fbb990bed63cc96ca18f62e2181db (v1.3.0)
* Mon Mar  6 2017 ygao@suse.com
- Clarify documentation around watchdog option (-W)
- Fix node-name handling in structs - bail out if too long
- man: Update man page to use pcmk_delay_max over start-delay (bsc#993032)
  * Drop bug-993032_sbd-man-pcmk_delay_max.patch which has been merged upstream
- use LDADD instead of LDFLAGS to fix build failure with ld --as-needed
  * Drop obsolete add-explicit-libs.patch
- Set SBD_STARTMODE to "always" by default
- Upstream version cs: 4ee36fa33b57a1ad95678363911cfb02a92e1edb
* Fri Feb 24 2017 ygao@suse.com
- Correctly find the pacemaker remote process
- Pacemaker remote must be allowed to start in parallel to sbd
- Only log 'healthy' when a servant was previously outdated
- Ensure the correct callbacks are always configured
- Streamline the initial cluster connection
- Non-disk servants start off as outdated until we hear from them
- Correctly check if the new servant is a disk
- Ensure crm_system_name is set to avoid SEGFAULT when connecting to the cluster
- Repair diskless startup (fate#321017)
- Enable the cluster check module
- systemd: Provide sbd_remote.service file for pacemaker remote nodes (bsc#962287)
  * Drop sbd_remote.service which has been merged upstream
- Simplified check for disk vs. non-disk servants
- Implement a new mode that gives priority to the cluster servants
- Support pacemaker remote as a cluster connect type that we can monitor
- Attempt to reconnect to the cluster after a failure
- Only continue tickling the watchdog without quorum if we have non-disk elements
- Notify the parent explicitly when the cluster connection goes away
- Track the number of servants and disks differently
- Cluster servant focuses exclusively on having a live cluster connection
- Automatically scale timeout_watchdog_warn with timeout_watchdog
- Differentiate between when a node is offline and unknown
- Gracefully handle an empty CIB
- Repair startup when no disks are present (fate#321017)
- Allow the watchdog timeout to be specified via the environment
- Self terminate when quorum is lost and the admin configured no-quorum-policy=suicide (bsc#950415)
  * Drop obsolete bug-950415_sbd-pacemaker-segfault.patch
- Prevent watchdogdev variable from being erased on fork()
- Fix the parsing of devices from the environment
- Let systemd own where the pidfile lives
- Use the pacemaker corefile directory
- Repair the SBD_STARTMODE handling and allow startup without a disk partition (fate#321017)
- Batch up the processing of cib updates but cap the maximum delay
- Simplify the systemd unit file by reading options from the environment
- Drop dependancy on clplumbing
  * Drop obsolete sbd-configure-libcoroipcc.patch
- Pacemaker: Fix compilation when building against corosync 2.x
  * Drop obsolete sbd-pacemaker.patch
- Upstream version cs: c511b0692784a7085df4b1ae35748fb318fa79ee
* Wed Aug 31 2016 ygao@suse.com
- man: Update man page to use pcmk_delay_max over start-delay (bsc#993032)
  * bug-993032_sbd-man-pcmk_delay_max.patch
* Wed Jul 20 2016 ygao@suse.com
- spec: Update the Url of the project
* Thu Jun 30 2016 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
- Use pgkconfig dependencies (and only those that are really needed)
- Remove systemd conditions as the only distro versions we build
  against have systemd
- Disable the werror cflags addition, we always build without it
  distro wide
* Tue May 17 2016 kgronlund@suse.com
- Update to version 1.2.1.git.1463482437.d6bd23a:
  * Add support for diskless sbd mode
- Remove outdated patches:
  * Remove sbd-pacemaker.patch
  * Remove sbd-configure-libcoroipcc.patch
  * Remove bug-950415_sbd-pacemaker-segfault.patch
* Tue Jan 19 2016 ygao@suse.com
- systemd: Provide sbd_remote.service file for pacemaker remote nodes (bsc#962287)
* Thu Oct 15 2015 ygao@suse.com
- pacemaker: Prevent potential segfault caused by use-of-NULL on checking node state (bsc#950415)
  * bug-950415_sbd-pacemaker-segfault.patch
* Wed Jun 24 2015 lmb@suse.com
- Trigger rebuild of sbd against more recent pacemaker packages (no code
  change) (bnc#934919)
* Fri Sep  5 2014 lmb@suse.com
- Update to version 1.2.1.git.1409904429.39dee2a:
  + Medium: adjust timeout for s390(x) to be compatible with vmwatchdog (bnc#895103)
* Fri Aug 15 2014 lmb@suse.com
- Update to version 1.2.1.git.1408100832.f0a4a63:
  + systemd: Start sbd before corosync instead of pacemaker (bnc#892078)
  + systemd: allow delaying start of post-sbd units (bnc#888935)
- Update _service file.
* Thu Jun 12 2014 lmb@suse.com
- Add _service to pull from latest git.
* Thu Jun  5 2014 lmb@suse.com
- pacemaker: improve XML performance and avoid crash with pacemaker >=
  1.1.12 (bnc#881231)
- man: correct syntax in example for the CIB configuration
- cs: 6f717f5
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Thu Mar 27 2014 lmb@suse.com
- sbd: Allow the watchdog to be explicitly disabled (bnc#865365)
- rpm: use the short git hash in the changelog from now on.
- cs: b96ac28
* Thu Mar 27 2014 lmb@suse.com
- systemd: ensure that sbd is activated after systemd module loading and
  the iSCSI initator (bnc#869612)
- Start-up: make sbd wait a configurable amount of time for devices to
  appear on boot (bnc#869612)
- Downgrade the logging during the initial wait to a debug log to avoid
  log flooding.
- cs: 512b71dc209744e505bf62d7ccddb70854fe7407
* Thu Oct 10 2013 lmb@suse.com
- systemd support
- /etc/sysconfig/sbd template added
- sbd: Add -p option to specify a pidfile
- sbd-pacemaker: detect whether to run the AIS plugin quorum check at
  runtime
- cs: d7df351e09f903be79495dbe312cf670f1747ef2
* Tue Oct  1 2013 lmb@suse.com
- License update in source files and spec file
- agent: detect if the stonith-timeout is too low (bnc#841010)
- agent: auto-correct pacemaker configuration if a too short timeout is
  detected. This can be disabled using the timeout_bypass option.
  (bnc#841010)
- man: explain why stonith-timeout needs to be larger than msgwait
- Drop fix-check-lib-lib-order.patch: merged upstream
- cs: 3757c4f6bc80146077cb2e019537c44d288f414d
* Fri Sep 13 2013 lmb@suse.com
- Add copyright comment to spec file.
* Tue Jul 30 2013 ygao@suse.com
- Added sbd-pacemaker.patch: Remove use of ais_fd_sync which only exists
  in corosync-1.x-based pacemaker plugin
- Added sbd-configure-libcoroipcc.patch: No longer check libcoroipcc
  when configuring
- Added add-explicit-libs.patch: add explicit libraries to build
  process.
* Thu Jul  4 2013 lmb@suse.com
- sbd-pacemaker: Improve performance
- sbd-pacemaker: handle transient failures of the CIB update processing
- sbd-pacemaker: Log two more cases where pacemaker state could become
  unhealthy
- Bump version number to 1.2.0
- cs: ffca2d93872b81f8b10ef1164c024005576afd4b
* Fri Jun 28 2013 lmb@suse.com
- sbd-pacemaker: update to support build with pacemaker-1.1.10
* Wed May 22 2013 tserong@suse.com
- Fix library link order, add required libraries explicitly
  + fix-check-lib-lib-order.patch
  + add-explicit-libs.patch
* Mon Mar 25 2013 lmb@suse.com
- Introduce -S option to prevent automatic start if the node was
  previously fenced (bnc#812195)
- Reduce number of scenarios where usage help is printed (bnc#812191)
- cs: 1837fd8cc64a
* Wed Feb 27 2013 lmb@suse.com
- Introduce minor header version and add a UUID (bnc#804991)
- Add debug mode level 3 to allow logs to flush, but do actually
  reboot.
- cs: 9641481ebc9b
* Thu Nov 22 2012 lmb@novell.com
- Failure to set watchdog interval is now fatal (bnc#790894)
- cs: d262617db1eb
* Thu Nov 15 2012 lmb@novell.com
- Upstream merge of compatibility changes for pacemaker 1.1.8
- cs: 52ddf89aa96b
* Mon Oct 22 2012 ygao@suse.com
- Changes for being compatible with pacemaker >= 1.1.8
* Fri Sep 28 2012 lmb@novell.com
- Increase sbd's scheduling priority to the maximum (bnc#779259)
- Print proper defaults for -t/-F in sbd help (manpage was already
  correct)
- cs: 6689be9d3aec
* Mon Jun 18 2012 lmb@novell.com
- Remove explicit conflict with cluster-glue.
* Mon Jun 18 2012 lmb@novell.com
- Include a man page for the sbd command.
- Conflict with older versions of ClusterTools2 due to a file
  conflict.
- cs: 3a371cd0f200
* Tue Jun 12 2012 lmb@novell.com
- cs: 68e33d323c6e
- Include more detail on the result of failed async IO in log
- Fix access to unallocated memory in servant
* Wed May 30 2012 lmb@novell.com
- cs: 7d7e0803def7
- Log once if pacemaker state prevented self-fence due to lost device
  majority
- Build using autoconf/autotool
* Tue May 29 2012 lmb@novell.com
- cs: d7c676111472
- Make write IO asynchronous as well.
- Ensure that each mbox will only be zeroed once.
- Initialize sysrq and enable reboot/poweroff flags.
- Unify async IO read/write paths.
* Fri May 25 2012 lmb@novell.com
- Make the code compile on SP1 too, though AIS integration is not
  available there.
* Fri May 25 2012 lmb@novell.com
- cs: dcf1f404b6b7
- Refresh pacemaker state once per second instead of only on CIB update
- Pacemaker state will only be accepted if it is fresh enough
- Refetch the full CIB periodically to notice stalls on notifications
- Request quorum state also from corosync/AIS, not just the CIB
* Thu May 24 2012 lmb@novell.com
- cs: 1cd63d9a962d
- Servants should only be considered live if reporting within
  timeout_io, not timeout_watchdog
- Successful delivery should not be logged at ERROR severity
* Thu May 24 2012 lmb@novell.com
- cs: 01b157f5cfee
- Ensure that sbd latency does not turn negative and thus would cause an
  unnecessary self-fence.
- Drop conflict with older version of cluster-glue; file level conflict
  is sufficient.
* Tue May 22 2012 lmb@novell.com
- cs: 7379080b64ea
- Take pacemaker quorum and node state into account for
  fencing decision (FATE#310625, bnc#767293)
- Adjust sbd servant restart intervals
- Allow setting a different watchdog timeout before crashdump
  (bnc#762300)
- Handle loss of connection to the CIB process properly
- Split sbd off cluster-glue
- Limit number of no restart messages printed (bnc#753559)
- Actually don't restart servants if restart limit reached
- Add debug mode via -Z commandline switch (bnc#753559)
- Fix allocation in the face of failures (bnc#753559)
- handle stuck IO better by explicitly informing our parent
  738295)
- Make servant restart logic more robust and verbose (bnc#738295)
- Make sure the restart limit set to zero works (bnc#738295)
- Use async io for reads (bnc#738295)
- Skip missing/broken devices during list/dump (bnc#761797)
- Add strategic log messages for debuggability
